@@ -32,8 +32,6 @@ from ..utils.errors import (
 
 
 DEFAULT_TRAIN_PARAMS = "[{\"name\":\"dataset\",\"type\":\"dataset\",\"suggest\":1}]"
-DEFAULT_EVAL_PARAMS = "[{\"name\":\"dataset\",\"type\":\"dataset\",\"suggest\":1},\
-                        {\"name\":\"model_path\",\"alias\":\"\",\"description\":\"\",\"type\":\"model\",\"suggest\":1}]"
 
 
 def sync_algorithm(
@@ -43,8 +41,6 @@ def sync_algorithm(
     archive_path: Optional[str]=None, # deprecated in 0.11.11, remove in 0.12.3
     entrypoint_training: Optional[str]=None,
     output_training: Optional[str]=None,
-    entrypoint_evaluation: Optional[str]=None, # deprecated in 0.11.11, remove in 0.12.3
-    output_evaluation: Optional[str]=None, # deprecated in 0.11.11, remove in 0.12.3
     mirror_name: Optional[str]="QUICKSTART",
     uploader: Optional[ResourceUploader]=None,
     polling: Union[float, int]=5,
@@ -55,15 +51,11 @@ def sync_algorithm(
             id=id,
             entrypoint_training=entrypoint_training,
             output_training=output_training,
-            entrypoint_evaluation=entrypoint_evaluation,
-            output_evaluation=output_evaluation,
             image_name=mirror_name,
         )
     else:
         deprecated = {
             'archive_path': archive_path,
-            'entrypoint_evaluation': entrypoint_evaluation,
-            'output_evaluation': output_evaluation,
         }
         for k, v in deprecated.items():
             if v:
@@ -87,8 +79,6 @@ def _sync_remote_algorithm(
     id: str,
     entrypoint_training: Optional[str]=None,
     output_training: Optional[str]=None,
-    entrypoint_evaluation: Optional[str]=None,
-    output_evaluation: Optional[str]=None,
     image_name: Optional[str]='QUICKSTART',
 ) -> Tuple[Algorithm, Optional[str]]:
     algo = Algorithm(id=id, load_detail=True)
@@ -97,7 +87,6 @@ def _sync_remote_algorithm(
         algo.entrypoint_training = entrypoint_training
     if output_training is not None:
         algo.output_training = output_training
-    # Eval things is temporarily deactivated, ignored here
     algo.save()
     algo.get_detail()
     return algo, None
@@ -209,7 +198,6 @@ def _create_new_algorithm(name: str) -> Algorithm:
         filename=f"{name}.zip", # legacy
         is_zipfile=True, # legacy
         train_params=DEFAULT_TRAIN_PARAMS,
-        evaluate_params=DEFAULT_EVAL_PARAMS,
         follows_anylearn_norm=False,
     )
     return algo
