@@ -16,8 +16,6 @@ from .utils import (
     make_name_by_path,
 )
 from ..interfaces import (
-    EvaluateSubTask,
-    EvaluateTask,
     Project,
     ProjectVisibility,
     QuotaGroup,
@@ -248,30 +246,6 @@ def _create_train_task(name: str,
     return train_task
 
 
-def _create_eval_task(name: str,
-                      model: Model,
-                      dataset: Dataset,
-                      model_hyperparam_name: str, 
-                      dataset_hyperparam_name: str,
-                      hyperparams: dict,
-                      gpu_num: int=1):
-    eval_params = dict({
-                           model_hyperparam_name: f"${model.id}",
-                           dataset_hyperparam_name: f"${dataset.id}",
-                       },
-                       **hyperparams)
-    eval_task = EvaluateTask(name=name,
-                             sub_tasks=[
-                                 EvaluateSubTask(model_id=model.id,
-                                                 files=[dataset.id],
-                                                 evaluate_params=eval_params,
-                                                 gpu_num=gpu_num)
-                             ])
-    eval_task.save()
-    eval_task.get_detail()
-    return eval_task
-
-
 def quick_train(algorithm_id: Optional[str]=None,
                 algorithm_name: Optional[str]=None,
                 algorithm_dir: Optional[Union[str, Path]]=None,
@@ -506,176 +480,6 @@ def quick_train(algorithm_id: Optional[str]=None,
     return train_task, algo, dset, project
 
 
-def quick_evaluate(model_id: Optional[str]=None,
-                   model_dir: Optional[Union[str,Path]]=None,
-                   model_archive: Optional[str]=None,
-                   algorithm_id: Optional[str]=None,
-                   algorithm_name: Optional[str]=None,
-                   algorithm_dir: Optional[Union[str, Path]]=None,
-                   algorithm_archive: Optional[str]=None,
-                   dataset_id: Optional[str]=None,
-                   dataset_dir: Optional[Union[str, Path]]=None,
-                   dataset_archive: Optional[str]=None,
-                   entrypoint: Optional[str]=None,
-                   output: Optional[str]=None,
-                   resource_uploader: ResourceUploader=None,
-                   resource_polling: Union[float, int]=5,
-                   model_hyperparam_name: str="model_path",
-                   dataset_hyperparam_name: str="dataset",
-                   hyperparams: dict={},
-                   gpu_num: int=1):
-    """
-    本地模型快速验证接口。
-
-    仅需提供本地资源和验证相关的信息，
-    即可在Anylearn后端引擎启动自定义模型/算法/数据集的验证：
-    
-    - 模型路径（文件目录或压缩包）
-    - 模型关联的算法路径（文件目录或压缩包）
-    - 数据集路径（文件目录或压缩包）
-    - 验证启动命令
-    - 验证结果输出路径（结果需写入文件）
-    - 验证超参数
-
-    本接口封装了Anylearn从零启动验证的一系列流程：
-
-    - 模型注册、上传
-    - 算法注册、上传
-    - 数据集注册、上传
-    - 验证任务创建
-
-    本地资源初次在Anylearn注册和上传时，
-    会在本地记录资源的校验信息。
-    下一次调用快速训练或快速验证接口时，
-    如果提供了相同的资源信息，
-    则不再重复注册和上传资源，
-    自动复用远程资源。
-
-    如有需要，也可向本接口传入已在Anylearn远程注册的模型、算法或数据集的ID，
-    省略资源创建的过程。
-
-    Parameters
-    ----------
-    model_id : :obj:`str`, optional
-        已在Anylearn远程注册的模型ID。
-    model_dir : :obj:`str`, optional
-        本地模型目录路径。
-    model_archive : :obj:`str`, optional
-        本地模型压缩包路径。
-    algorithm_id : :obj:`str`, optional
-        已在Anylearn远程注册的算法ID。
-    algorithm_name: :obj:`str`, optional
-        指定的算法名称。
-        注：同一用户的自定义算法的名称不可重复。
-        如有重复，则复用已存在的同名算法，
-        算法文件将被覆盖并提升版本。
-        原有版本仍可追溯。
-    algorithm_dir : :obj:`str`, optional
-        本地算法目录路径。
-    algorithm_archive : :obj:`str`, optional
-        本地算法压缩包路径。
-    dataset_id : :obj:`str`, optional
-        已在Anylearn远程注册的数据集ID。
-    dataset_dir : :obj:`str`, optional
-        本地数据集目录路径。
-    dataset_archive : :obj:`str`, optional
-        本地数据集压缩包路径。
-    entrypoint : :obj:`str`, optional
-        启动验证的入口命令。
-    output : :obj:`str`, optional
-        输出验证结果的相对路径（相对于模型关联的算法的目录）。
-    resource_uploader : :obj:`ResourceUploader`, optional
-        资源上传实现。
-        默认使用系统内置的同步上传器 :obj:`SyncResourceUploader` 。
-    resource_polling : :obj:`float|int`, optional
-        资源上传中轮询资源状态的时间间隔（单位：秒）。
-        默认为5秒。
-    model_hyperparam_name : :obj:`str`, optional
-        启动验证时，模型路径作为启动命令参数传入算法的参数名。
-        需指定长参数名，如 :obj:`--model` ，并省略 :obj:`--` 部分传入。
-        模型路径由Anylearn后端引擎管理。
-        默认为 :obj:`model_path` 。
-    dataset_hyperparam_name : :obj:`str`, optional
-        启动验证时，数据集路径作为启动命令参数传入算法的参数名。
-        需指定长参数名，如 :obj:`--data` ，并省略 :obj:`--` 部分传入。
-        数据集路径由Anylearn后端引擎管理。
-        默认为 :obj:`dataset` 。
-    hyperparams : :obj:`dict`, optional
-        验证超参数字典。
-        超参数将作为验证启动命令的参数传入算法。
-        超参数字典中的键应为长参数名，如 :obj:`--param` ，并省略 :obj:`--` 部分传入。
-        默认为空字典。
-    gpu_num : :obj:`int`, optional
-        向Anylearn后端引擎请求的GPU数量。
-        默认为1。
-
-    Returns
-    -------
-    EvaluateTask
-        创建的验证任务对象
-    Algorithm
-        在快速验证过程中创建或获取的算法对象
-    Model
-        在快速验证过程中创建或获取的模型对象
-    Dataset
-        在快速验证过程中创建或获取的数据集对象
-    """
-    # Algorithm
-    algo = sync_algorithm(
-        id=algorithm_id,
-        name=algorithm_name,
-        dir_path=algorithm_dir,
-        archive_path=algorithm_archive,
-        entrypoint_evaluation=entrypoint,
-        output_evaluation=output,
-        uploader=resource_uploader,
-        polling=resource_polling,
-    )
-
-    # Model
-    model, model_archive, model_checksum = _get_or_create_model(
-        id=model_id,
-        dir_path=model_dir,
-        archive_path=model_archive,
-        algorithm=algo
-    )
-    if model_archive:
-        # Local model registration
-        _upload_model(model=model,
-                      model_archive=model_archive,
-                      uploader=resource_uploader,
-                      polling=resource_polling)
-        DB().create_local_model(id=model.id, checksum=model_checksum)
-
-    # Dataset
-    dset, dataset_archive, dataset_checksum = _get_or_create_dataset(
-        id=dataset_id,
-        dir_path=dataset_dir,
-        archive_path=dataset_archive
-    )
-    if dataset_archive:
-        # Local dataset registration
-        _upload_dataset(dataset=dset,
-                        dataset_archive=dataset_archive,
-                        uploader=resource_uploader,
-                        polling=resource_polling)
-        DB().create_local_dataset(id=dset.id, checksum=dataset_checksum)
-    
-    # Evaluate task
-    eval_name = generate_random_name()
-    eval_task = _create_eval_task(
-        name=eval_name,
-        model=model,
-        dataset=dset,
-        model_hyperparam_name=model_hyperparam_name,
-        dataset_hyperparam_name=dataset_hyperparam_name,
-        hyperparams=hyperparams,
-        gpu_num=gpu_num
-    )
-
-    return eval_task, algo, model, dset
-
-
 def resume_unfinished_local_train_tasks():
     db = DB()
     local_list = db.get_unfinished_train_tasks()
