@@ -21,6 +21,8 @@ class TestAlgorithm(BaseTestCase):
                               'upload_time': "2020-01-01 00:00",
                               'tags': "tag1, tag2",
                               'follows_anylearn_norm': True,
+                              'git_address': "http://anylearn.testing/anylearn/TestAlgo1.git",
+                              'git_migrated': True,
                           },
                           {
                               'id': "ALGO002",
@@ -31,6 +33,8 @@ class TestAlgorithm(BaseTestCase):
                               'upload_time': "2020-01-02 00:00",
                               'tags': "tag3, tag4",
                               'follows_anylearn_norm': False,
+                              'git_address': "http://anylearn.testing/anylearn/TestAlgo2.git",
+                              'git_migrated': True,
                           },
                       ],
                       status=200)
@@ -76,13 +80,12 @@ class TestAlgorithm(BaseTestCase):
                           'owner': ["USER001"],
                           'tags': "tag1, tag2",
                           'train_params': '[{"test": "test"}]',
-                          'evaluate_params': '[{"test": "test"}]',
                           'mirror_id': "MIRR001",
                           'follows_anylearn_norm': True,
                           'entrypoint_training': "python train.py",
                           'output_training': "output",
-                          'entrypoint_evaluation': "python eval.py",
-                          'output_evaluation': "output",
+                          'git_address': "http://anylearn.testing/user001/TestAlgo1.git",
+                          'git_migrated': True,
                       }],
                       status=200)
         algo = Algorithm(id="ALGO001")
@@ -97,15 +100,11 @@ class TestAlgorithm(BaseTestCase):
         self.assertEqual(algo.owner[0], "USER001")
         self.assertEqual(algo.tags, "tag1, tag2")
         self.assertIsInstance(algo.train_params, list)
-        self.assertIsInstance(algo.evaluate_params, list)
         self.assertEqual(str(algo.train_params), "[{'test': 'test'}]")
-        self.assertEqual(str(algo.evaluate_params), "[{'test': 'test'}]")
         self.assertEqual(algo.mirror_id, "MIRR001")
         self.assertEqual(algo.follows_anylearn_norm, True)
         self.assertEqual(algo.entrypoint_training, "python train.py")
         self.assertEqual(algo.output_training, "output")
-        self.assertEqual(algo.entrypoint_evaluation, "python eval.py")
-        self.assertEqual(algo.output_evaluation, "output")
 
     @responses.activate
     def test_get_algo_detail_no_explicit_call_ok(self):
@@ -126,13 +125,12 @@ class TestAlgorithm(BaseTestCase):
                           'owner': ["USER001"],
                           'tags': "tag1, tag2",
                           'train_params': '[{"test": "test"}]',
-                          'evaluate_params': '[{"test": "test"}]',
                           'mirror_id': "MIRR001",
                           'follows_anylearn_norm': False,
                           'entrypoint_training': "python niart.py",
                           'output_training': "tuptuo",
-                          'entrypoint_evaluation': "python lave.py",
-                          'output_evaluation': "tuptuo",
+                          'git_address': "http://anylearn.testing/user001/TestAlgo1.git",
+                          'git_migrated': True,
                       }],
                       status=200)
         algo = Algorithm(id="ALGO001", load_detail=True)
@@ -147,15 +145,11 @@ class TestAlgorithm(BaseTestCase):
         self.assertEqual(algo.owner[0], "USER001")
         self.assertEqual(algo.tags, "tag1, tag2")
         self.assertIsInstance(algo.train_params, list)
-        self.assertIsInstance(algo.evaluate_params, list)
         self.assertEqual(str(algo.train_params), "[{'test': 'test'}]")
-        self.assertEqual(str(algo.evaluate_params), "[{'test': 'test'}]")
         self.assertEqual(algo.mirror_id, "MIRR001")
         self.assertEqual(algo.follows_anylearn_norm, False)
         self.assertEqual(algo.entrypoint_training, "python niart.py")
         self.assertEqual(algo.output_training, "tuptuo")
-        self.assertEqual(algo.entrypoint_evaluation, "python lave.py")
-        self.assertEqual(algo.output_evaluation, "tuptuo")
 
     @responses.activate
     def test_get_algo_detail_ko_403(self):
@@ -199,7 +193,6 @@ class TestAlgorithm(BaseTestCase):
                       status=200)
         algo = Algorithm(name="TestALGO001", filename="test.tar.gz",
                          train_params='[{"name": "test", "type": "int", "suggest": 1, "default": "0", "scope": "<0,1>"}]',
-                         evaluate_params='[{"name": "test", "type": "int", "suggest": 1, "default": "0", "scope": "<0,1>"}]',
                          mirror_id="MIRR001")
         result = algo.save()
         self.assertTrue(result)
@@ -211,12 +204,11 @@ class TestAlgorithm(BaseTestCase):
             algo.save()
         e = ctx.exception
         self.assertIsInstance(e, AnyLearnMissingParamException)
-        self.assertEqual(e.msg, "Algorithm缺少必要字段：['name', 'filename', 'mirror_id', 'train_params', 'evaluate_params']")
+        self.assertEqual(e.msg, "Algorithm缺少必要字段：['name', 'filename', 'mirror_id', 'train_params']")
 
     # def test_create_algo_ko_empty_entrypoint_training_output_training(self):
     #     algo = Algorithm(name="TestALGO250", filename="test.tar.gz",
     #                      train_params='[{"name": "test", "type": "int", "suggest": 1, "default": "0", "scope": "<0,1>"}]',
-    #                      evaluate_params='[{"name": "test", "type": "int", "suggest": 1, "default": "0", "scope": "<0,1>"}]',
     #                      mirror_id="MIRR001", follows_anylearn_norm=False)
     #     with self.assertRaises(AnyLearnMissingParamException) as ctx:
     #         algo.save()
@@ -230,7 +222,6 @@ class TestAlgorithm(BaseTestCase):
                       json={'msg': "Unknown response"}, status=201)
         algo = Algorithm(name="TestAlgo", filename="ALGO250.tar.gz",
                          train_params='[{"test": "test"}]',
-                         evaluate_params='[{"test": "test"}]',
                          mirror_id="MIRR001")
         with self.assertRaises(AnyLearnException) as ctx:
             algo.save()
@@ -277,7 +268,7 @@ class TestAlgorithm(BaseTestCase):
     @responses.activate
     def test_delete_algo_ok(self):
         responses.add(responses.DELETE,
-                      url=self._url("algorithm/delete?id=ALGO001"),
+                      url=self._url("algorithm/delete?id=ALGO001&force=0"),
                       match_querystring=True,
                       json={'data': "ALGO001", 'message': "算法删除成功"},
                       status=200)
@@ -291,7 +282,7 @@ class TestAlgorithm(BaseTestCase):
     @responses.activate
     def test_delete_algo_ko_unknown_response(self):
         responses.add(responses.DELETE,
-                      url=self._url("algorithm/delete?id=ALGO250"),
+                      url=self._url("algorithm/delete?id=ALGO250&force=0"),
                       match_querystring=True,
                       json={'msg': "Unknown response"},
                       status=204)
@@ -313,7 +304,7 @@ class TestAlgorithm(BaseTestCase):
                 {"name": "test2", "type": "int", "suggest": 1, "default": "2", "scope": "<0,2>"}
             ]
         '''
-        algo = Algorithm(train_params=json_params, evaluate_params=json_params)
+        algo = Algorithm(train_params=json_params)
         
         self.assertIsInstance(algo.required_train_params, list)
         self.assertEqual(len(algo.required_train_params), 1)
@@ -322,11 +313,3 @@ class TestAlgorithm(BaseTestCase):
         self.assertEqual(len(algo.default_train_params), 2)
         self.assertEqual(algo.default_train_params['test1'], '1')
         self.assertEqual(algo.default_train_params['test2'], '2')
-
-        self.assertIsInstance(algo.required_evaluate_params, list)
-        self.assertEqual(len(algo.required_evaluate_params), 1)
-        self.assertEqual(algo.required_evaluate_params[0]['name'], 'test0')
-        self.assertIsInstance(algo.default_evaluate_params, dict)
-        self.assertEqual(len(algo.default_evaluate_params), 2)
-        self.assertEqual(algo.default_evaluate_params['test1'], '1')
-        self.assertEqual(algo.default_evaluate_params['test2'], '2')
